@@ -242,6 +242,16 @@ fn fold_sum_i32_2d_stride(bench: &mut test::Bencher)
     });
 }
 
+#[bench]
+fn fold_sum_i32_2d_transpose(bench: &mut test::Bencher)
+{
+    let a = Array::<i32, _>::zeros((64, 64));
+    let a = a.t();
+    bench.iter(|| {
+        a.fold(0, |acc, &x| acc + x)
+    });
+}
+
 #[bench]
 fn add_2d_regular(bench: &mut test::Bencher)
 {
